AccessControlRule class

A rule that controls access to an Amazon WorkMail organization.

Constructors

AccessControlRule({List<String>? actions, DateTime? dateCreated, DateTime? dateModified, String? description, AccessControlRuleEffect? effect, List<String>? ipRanges, String? name, List<String>? notActions, List<String>? notIpRanges, List<String>? notUserIds, List<String>? userIds})
AccessControlRule.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<String>?
Access protocol actions to include in the rule. Valid values include ActiveSync, AutoDiscover, EWS, IMAP, SMTP, WindowsOutlook, and WebMail.
final
dateCreated → DateTime?
The date that the rule was created.
final
dateModified → DateTime?
The date that the rule was modified.
final
description → String?
The rule description.
final
effect → AccessControlRuleEffect?
The rule effect.
final
hashCode → int
The hash code for this object.
no setterinherited
ipRanges → List<String>?
IPv4 CIDR ranges to include in the rule.
final
name → String?
The rule name.
final
notActions → List<String>?
Access protocol actions to exclude from the rule. Valid values include ActiveSync, AutoDiscover, EWS, IMAP, SMTP, WindowsOutlook, and WebMail.
final
notIpRanges → List<String>?
IPv4 CIDR ranges to exclude from the rule.
final
notUserIds → List<String>?
User IDs to exclude from the rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds → List<String>?
User IDs to include in the rule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited