Domain class

The domain to associate with an Amazon WorkMail organization.

When you configure a domain hosted in Amazon Route 53 (Route 53), all recommended DNS records are added to the organization when you create it. For more information, see Adding a domain in the Amazon WorkMail Administrator Guide.

Constructors

Domain({String? domainName, String? hostedZoneId})

Properties

domainName → String?
The fully qualified domain name.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String?
The hosted zone ID for a domain hosted in Route 53. Required when configuring a domain hosted in Route 53.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited