FolderConfiguration class

The configuration applied to an organization's folders by its retention policy.

Constructors

FolderConfiguration({required RetentionAction action, required FolderName name, int? period})
FolderConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

action → RetentionAction
The action to take on the folder contents at the end of the folder configuration period.
final
hashCode → int
The hash code for this object.
no setterinherited
name → FolderName
The folder name.
final
period → int?
The period of time at which the folder configuration action is applied.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited