Group class

The representation of an Amazon WorkMail group.

Constructors

Group({DateTime? disabledDate, String? email, DateTime? enabledDate, String? id, String? name, EntityState? state})
Group.fromJson(Map<String, dynamic> json)
factory

Properties

disabledDate → DateTime?
The date indicating when the group was disabled from Amazon WorkMail use.
final
email → String?
The email of the group.
final
enabledDate → DateTime?
The date indicating when the group was enabled for Amazon WorkMail use.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the group.
final
name → String?
The name of the group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → EntityState?
The state of the group, which can be ENABLED, DISABLED, or DELETED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited