ListGroupMembersResponse class

Constructors

ListGroupMembersResponse({List<Member>? members, String? nextToken})
ListGroupMembersResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
members → List<Member>?
The members associated to the group.
final
nextToken → String?
The token to use to retrieve the next page of results. The first call does not contain any tokens.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited