Member class

The representation of a user or group.

Constructors

Member({DateTime? disabledDate, DateTime? enabledDate, String? id, String? name, EntityState? state, MemberType? type})
Member.fromJson(Map<String, dynamic> json)
factory

Properties

disabledDate → DateTime?
The date indicating when the member was disabled from Amazon WorkMail use.
final
enabledDate → DateTime?
The date indicating when the member was enabled for Amazon WorkMail use.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the member.
final
name → String?
The name of the member.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → EntityState?
The state of the member, which can be ENABLED, DISABLED, or DELETED.
final
type → MemberType?
A member can be a user or group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited