User class

The representation of an Amazon WorkMail user.

Constructors

User({DateTime? disabledDate, String? displayName, String? email, DateTime? enabledDate, String? id, String? name, EntityState? state, UserRole? userRole})
User.fromJson(Map<String, dynamic> json)
factory

Properties

disabledDate → DateTime?
The date indicating when the user was disabled from Amazon WorkMail use.
final
displayName → String?
The display name of the user.
final
email → String?
The email of the user.
final
enabledDate → DateTime?
The date indicating when the user was enabled for Amazon WorkMail use.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the user.
final
name → String?
The name of the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → EntityState?
The state of the user, which can be ENABLED, DISABLED, or DELETED.
final
userRole → UserRole?
The role of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited